==> bibledit-1.4.tar.gz: bibledit-1.4/src/splashscreen.cpp <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "libraries.h"
#include "utilities.h"
#include <libgen.h>
#include <glib.h>
#include <config.h>
#include "splashscreen.h"


#define BIBLEDIT_SPLASH "bibledit.splash"
#define KILLALL "killall"


SplashScreen::SplashScreen (const ustring& information)
{
  ustring command = BIBLEDIT_SPLASH;
  command.append (" '" + information + "'");
  command.append (" &"); // Runs in background.
  system (command.c_str());
  // Wait until program runs, to give the splash screen a change to set up.
  g_usleep (500000);
}


SplashScreen::~SplashScreen ()
{
  ustring command;
  command.append (KILLALL);
  command.append (" ");
  command.append (BIBLEDIT_SPLASH);
  system (command.c_str());
}


void SplashScreen::set_fraction (double fraction)
{
  if (fraction > 1)
    fraction = 1;
  while (fraction >= current_fraction + 0.1) {
    set_fraction_execute (true);
    current_fraction += 0.1;
  }
  while (fraction >= current_fraction + 0.01) {
    set_fraction_execute (false);
    current_fraction += 0.01;
  }
}


void SplashScreen::set_fraction_execute (bool ten_percent)
{
  ustring command;
  command.append (KILLALL);
  if (ten_percent)
    command.append (" -USR2 ");
  else
    command.append (" -USR1 ");
  command.append (BIBLEDIT_SPLASH);
  system (command.c_str());
}

==> bibledit_1.7.orig.tar.gz: bibledit-1.7/src/splashscreen.cpp <==
/*
** Copyright (C) 2003-2006 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "libraries.h"
#include "utilities.h"
#include <libgen.h>
#include <glib.h>
#include <config.h>
#include "splashscreen.h"
#include "gwrappers.h"
#include "directories.h"


#define BIBLEDIT_SPLASH "bibledit.splash"
#define KILLALL "killall"


SplashScreen::SplashScreen (int dummy)
{
  current_information = "Bibledit";
  current_percentage = 0;
  ustring command = BIBLEDIT_SPLASH;
  command.append (" &"); // Runs in background.
  system (command.c_str());
  set_values ();
}


SplashScreen::~SplashScreen ()
{
  current_percentage = 100;
  set_values ();
}


void SplashScreen::percentage (int percentage)
{
  current_percentage = percentage;
  set_values ();
}


void SplashScreen::information (const ustring& information)
{
  current_information = information;
  set_values ();
}


void SplashScreen::set_values ()
{
  ustring filename = gw_build_filename (directories_get_temp(), "bibledit.splash");
  WriteText wt (filename);
  wt.text (convert_to_string (current_percentage) + " " + current_information);
}
